@@ -42,6 +42,7 @@ type serverConfig struct {
 	ReceiveWindowConn   uint64 `json:"recv_window_conn"`
 	ReceiveWindowClient uint64 `json:"recv_window_client"`
 	MaxConnClient       int    `json:"max_conn_client"`
+	DisableMTUDiscovery bool   `json:"disable_mtu_discovery"`
 }
 
 func (c *serverConfig) Check() error {
@@ -115,15 +116,16 @@ type clientConfig struct {
 		Listen  string `json:"listen"`
 		Timeout int    `json:"timeout"`
 	} `json:"tproxy_udp"`
-	ACL               string `json:"acl"`
-	Obfs              string `json:"obfs"`
-	Auth              []byte `json:"auth"`
-	AuthString        string `json:"auth_str"`
-	ServerName        string `json:"server_name"`
-	Insecure          bool   `json:"insecure"`
-	CustomCA          string `json:"ca"`
-	ReceiveWindowConn uint64 `json:"recv_window_conn"`
-	ReceiveWindow     uint64 `json:"recv_window"`
+	ACL                 string `json:"acl"`
+	Obfs                string `json:"obfs"`
+	Auth                []byte `json:"auth"`
+	AuthString          string `json:"auth_str"`
+	ServerName          string `json:"server_name"`
+	Insecure            bool   `json:"insecure"`
+	CustomCA            string `json:"ca"`
+	ReceiveWindowConn   uint64 `json:"recv_window_conn"`
+	ReceiveWindow       uint64 `json:"recv_window"`
+	DisableMTUDiscovery bool   `json:"disable_mtu_discovery"`
 }
 
 func (c *clientConfig) Check() error {
